Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1110)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/preferences/website/Website.java

Issue 1864163005: Switch Cookie to use ContentSettingException instead of CookieInfo on Android (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: one missing comments to be addressed Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/preferences/website/Website.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/preferences/website/Website.java b/chrome/android/java/src/org/chromium/chrome/browser/preferences/website/Website.java
index f446fa2638b5ec40f8e8f11bf04a9f2e484e72e9..09644bfdfb864df636b442fb608a86b0702457a1 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/preferences/website/Website.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/preferences/website/Website.java
@@ -29,7 +29,7 @@ public class Website implements Serializable {
private ContentSettingException mBackgroundSyncExceptionInfo;
private CameraInfo mCameraInfo;
- private CookieInfo mCookieInfo;
+ private ContentSettingException mCookieException;
private FullscreenInfo mFullscreenInfo;
private GeolocationInfo mGeolocationInfo;
private ContentSettingException mJavaScriptException;
@@ -128,33 +128,29 @@ public class Website implements Serializable {
}
/**
* Sets the CookieInfo object for this site.
*/
- public void setCookieInfo(CookieInfo info) {
- mCookieInfo = info;
- WebsiteAddress embedder = WebsiteAddress.create(info.getEmbedder());
- if (embedder != null) {
- mSummary = embedder.getTitle();
- }
+ public void setCookieException(ContentSettingException exception) {
+ mCookieException = exception;
}
- public CookieInfo getCookieInfo() {
- return mCookieInfo;
+ public ContentSettingException getCookieException() {
+ return mCookieException;
}
/**
* Gets the permission that governs cookie preferences.
*/
public ContentSetting getCookiePermission() {
- return mCookieInfo != null ? mCookieInfo.getContentSetting() : null;
+ return mCookieException != null ? mCookieException.getContentSetting() : null;
}
/**
* Sets the permission that govers cookie preferences for this site.
*/
public void setCookiePermission(ContentSetting value) {
- if (mCookieInfo != null) {
- mCookieInfo.setContentSetting(value);
+ if (mCookieException != null) {
+ mCookieException.setContentSetting(value);
}
}
@@ -128,33 +128,29 @@ public class Website implements Serializable {
}
/**
- * Sets the CookieInfo object for this site.
+ * Sets the Cookie exception info for this site.
*/

Powered by Google App Engine
This is Rietveld 408576698